Method: QuickBase::Client#getAuthenticationXMLforRequest

Defined in:
lib/QuickBaseClient.rb

#getAuthenticationXMLforRequest(api_Request) ⇒ Object

Returns the request XML for either a ticket or a username and password. The XML includes a apptoken if one has been set.



303
304
305
306
# File 'lib/QuickBaseClient.rb', line 303

def getAuthenticationXMLforRequest( api_Request )
   @authenticationXML = ""
   @authenticationXML = toXML( :usertoken, @usertoken )
end